@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2022  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -26,32 +26,34 @@ ASObject::ASObject(QVariantMap objectMap,
     m_originalObjectMap = objectMap;
 
     /// Meta information
-    m_id = ASPerson::cleanupId(objectMap.value("id").toString());
+    m_id = ASPerson::cleanupId(objectMap.value(QStringLiteral("id"))
+                                        .toString());
 
-    m_type = objectMap.value("objectType").toString();
-    m_url = objectMap.value("url").toString();
-    m_createdAt = objectMap.value("published").toString();
-    m_updatedAt = objectMap.value("updated").toString();
+    m_type = objectMap.value(QStringLiteral("objectType")).toString();
+    m_url = objectMap.value(QStringLiteral("url")).toString();
+    m_createdAt = objectMap.value(QStringLiteral("published")).toString();
+    m_updatedAt = objectMap.value(QStringLiteral("updated")).toString();
 
     // FIXME: still missing some fields...
-    QVariantMap locationMap = objectMap.value("location").toMap();
-    m_locationName = locationMap.value("displayName").toString();
-    m_locationFormatted = locationMap.value("address").toMap()
-                                     .value("formatted").toString();
-    m_locationCountry = locationMap.value("address").toMap()
-                                   .value("country").toString();
+    QVariantMap locationMap = objectMap.value(QStringLiteral("location"))
+                                       .toMap();
+    m_locationName = locationMap.value(QStringLiteral("displayName")).toString();
+    m_locationFormatted = locationMap.value(QStringLiteral("address")).toMap()
+                                     .value(QStringLiteral("formatted")).toString();
+    m_locationCountry = locationMap.value(QStringLiteral("address")).toMap()
+                                   .value(QStringLiteral("country")).toString();
 
 
     // Author
-    m_author = new ASPerson(objectMap.value("author").toMap(), this);
+    m_author = new ASPerson(objectMap.value(QStringLiteral("author")).toMap(), this);
 
     // This will hold the date when the object was deleted, or empty if it wasn't
-    m_deleted = objectMap.value("deleted").toString();
+    m_deleted = objectMap.value(QStringLiteral("deleted")).toString();
 
-    m_liked = objectMap.value("liked").toBool();
+    m_liked = objectMap.value(QStringLiteral("liked")).toBool();
 
     // The object to which this one replies, if any (note to which a comment replies, etc)
-    m_inReplyToMap = objectMap.value("inReplyTo").toMap();
+    m_inReplyToMap = objectMap.value(QStringLiteral("inReplyTo")).toMap();
 
 
     ///
@@ -66,47 +68,47 @@ ASObject::ASObject(QVariantMap objectMap,
          * (for private images on remote servers)
          */
         qDebug() << "Trying Proxyed thumbnail image";
-        m_smallImageUrl = objectMap.value("image").toMap()
-                                   .value("pump_io").toMap()
-                                   .value("proxyURL").toString();
+        m_smallImageUrl = objectMap.value(QStringLiteral("image")).toMap()
+                                   .value(QStringLiteral("pump_io")).toMap()
+                                   .value(QStringLiteral("proxyURL")).toString();
 
         // And if that's empty, use regular image->url
         if (m_smallImageUrl.isEmpty())
         {
             qDebug() << "Trying direct thumbnail image";
-            m_smallImageUrl = objectMap.value("image").toMap()
-                                       .value("url").toString();
+            m_smallImageUrl = objectMap.value(QStringLiteral("image")).toMap()
+                                       .value(QStringLiteral("url")).toString();
         }
 
 
         // Same for the full size image
-        m_imageUrl = objectMap.value("fullImage").toMap()
-                              .value("pump_io").toMap()
-                              .value("proxyURL").toString();
+        m_imageUrl = objectMap.value(QStringLiteral("fullImage")).toMap()
+                              .value(QStringLiteral("pump_io")).toMap()
+                              .value(QStringLiteral("proxyURL")).toString();
         qDebug() << "Trying Proxyed fullImage";
 
         // If that's empty, use regular fullImage->url field
         if (m_imageUrl.isEmpty())
         {
             qDebug() << "Trying direct fullImage";
-            m_imageUrl = objectMap.value("fullImage").toMap()
-                                  .value("url").toString();
+            m_imageUrl = objectMap.value(QStringLiteral("fullImage")).toMap()
+                                  .value(QStringLiteral("url")).toString();
         }
 
-        m_imageWidth = objectMap.value("fullImage").toMap()
-                                .value("width").toInt();
-        m_imageHeight = objectMap.value("fullImage").toMap()
-                                 .value("height").toInt();
+        m_imageWidth = objectMap.value(QStringLiteral("fullImage")).toMap()
+                                .value(QStringLiteral("width")).toInt();
+        m_imageHeight = objectMap.value(QStringLiteral("fullImage")).toMap()
+                                 .value(QStringLiteral("height")).toInt();
 
         // If it's STILL empty, use the thumbnail also as full image
         if (m_imageUrl.isEmpty())
         {
             m_imageUrl = m_smallImageUrl;
-            m_imageWidth = objectMap.value("image").toMap()
-                                    .value("width").toInt();
-            m_imageHeight = objectMap.value("image").toMap()
-                                     .value("height").toInt();
-        }        
+            m_imageWidth = objectMap.value(QStringLiteral("image")).toMap()
+                                    .value(QStringLiteral("width")).toInt();
+            m_imageHeight = objectMap.value(QStringLiteral("image")).toMap()
+                                     .value(QStringLiteral("height")).toInt();
+        }
 
         // And if there's no small image for some reason, use the full one as thumbnail
         if (m_smallImageUrl.isEmpty())
@@ -117,12 +119,12 @@ ASObject::ASObject(QVariantMap objectMap,
         qDebug() << "postImage:" << m_imageUrl << "> Small:" << m_smallImageUrl;
 
         // To have a filename with extension, even when downloading from proxyURL's
-        m_attachmentPureUrl = objectMap.value("fullImage").toMap()
-                                       .value("url").toString();
+        m_attachmentPureUrl = objectMap.value(QStringLiteral("fullImage")).toMap()
+                                       .value(QStringLiteral("url")).toString();
         if (m_attachmentPureUrl.isEmpty())
         {
-            m_attachmentPureUrl = objectMap.value("image").toMap()
-                                           .value("url").toString();
+            m_attachmentPureUrl = objectMap.value(QStringLiteral("image")).toMap()
+                                           .value(QStringLiteral("url")).toString();
         }
     }
 
@@ -194,9 +196,9 @@ ASObject::ASObject(QVariantMap objectMap,
 
 
     // Title can be in non-image posts, too!
-    m_title = objectMap.value("displayName").toString().trimmed();
-    m_summary = objectMap.value("summary").toString();
-    m_content = objectMap.value("content").toString();
+    m_title = objectMap.value(QStringLiteral("displayName")).toString().trimmed();
+    m_summary = objectMap.value(QStringLiteral("summary")).toString();
+    m_content = objectMap.value(QStringLiteral("content")).toString();
 
     m_likesCount = objectMap.value("likes").toMap().value("totalItems").toInt();
     m_commentsCount = objectMap.value("replies").toMap().value("totalItems").toInt();
