@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2022  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -151,6 +151,15 @@ ImageViewer::ImageViewer(QString url, QSize imageSize,
             this, &ImageViewer::rotateRight);
 
 
+    m_invertColorsButton = new QPushButton(QIcon::fromTheme("color-fill", /// TMP FIXME
+                                                            QIcon(":/images/button-filter.png")),
+                                           tr("Invert"),
+                                           this);
+    m_invertColorsButton->setDisabled(true);
+    connect(m_invertColorsButton, &QPushButton::clicked,
+            this, &ImageViewer::invertColors);
+
+
     m_infoLabel = new QLabel("~    ~    ~    ~    ~    ~    ~", this);
     m_infoLabel->setAlignment(Qt::AlignCenter);
 
@@ -186,6 +195,7 @@ ImageViewer::ImageViewer(QString url, QSize imageSize,
     m_buttonsLayout->addWidget(m_zoomOutButton);
     m_buttonsLayout->addWidget(m_rotateLeftButton);
     m_buttonsLayout->addWidget(m_rotateRightButton);
+    m_buttonsLayout->addWidget(m_invertColorsButton);
     m_buttonsLayout->addWidget(m_infoLabel, 1);
     m_buttonsLayout->addWidget(m_closeButton);
 
@@ -243,9 +253,10 @@ ImageViewer::ImageViewer(QString url, QSize imageSize,
                      + m_zoomOutButton->sizeHint().width()
                      + m_rotateLeftButton->sizeHint().width()
                      + m_rotateRightButton->sizeHint().width()
+                     + m_invertColorsButton->sizeHint().width()
                      + m_infoLabel->sizeHint().width()
                      + m_closeButton->sizeHint().width()
-                     + (m_buttonsLayout->spacing() * 12); // With a few extra spacings
+                     + (m_buttonsLayout->spacing() * 13); // With a few extra spacings
     if (m_imageIsAnimated)
     {
         desiredWidth += m_restartButton->sizeHint().width()
@@ -421,6 +432,8 @@ void ImageViewer::loadImage(QString url, QSize expectedSize)
         m_rotateLeftAction->setEnabled(true);
         m_rotateRightAction->setEnabled(true);
 
+        m_invertColorsButton->setEnabled(true);
+
         m_toggleFitFullAction->setEnabled(true);
 
         m_autoFitTimer->start();
@@ -691,6 +704,16 @@ void ImageViewer::rotateRight()
 }
 
 
+void ImageViewer::invertColors()
+{
+    QImage invertedImage = m_originalPixmap.toImage();
+    invertedImage.invertPixels();
+    m_originalPixmap = QPixmap::fromImage(invertedImage);
+
+    m_graphicsPixmapItem->setPixmap(m_originalPixmap);
+}
+
+
 void ImageViewer::onFitFullToggled()
 {
     if (m_fitToWindow)
