@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2022  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -240,12 +240,12 @@ private:
     ////////////////////////////////////// Menus
     QMenu *sessionMenu;
     QMenu *viewMenu;
-    QMenu *settingsMenu;
-    QMenu *helpMenu;
+    QMenu *m_settingsMenu;
+    QMenu *m_helpMenu;
 
-    QMenu *trayContextMenu;
+    QMenu *m_trayContextMenu;
     QAction *m_trayTitleAction;
-    QAction *trayShowWindowAction;
+    QAction *m_trayShowWindowAction;
 
     QAction *sessionUpdateMainTimeline;
     QAction *sessionUpdateDirectTimeline;
@@ -297,42 +297,42 @@ private:
 
     QPushButton *m_statusAccountButton; // Shown when no account is configured
     bool m_statusAccountButtonUsed;
-    QProgressBar *initializationProgressBar;
+    QProgressBar *m_initProgressBar;
 
 
-    QDockWidget *sideDockWidget;
-    QWidget *sideDockTitleWidget;
-    QWidget *leftSideWidget;
-    QVBoxLayout *leftLayout;
+    QDockWidget *m_sideDockWidget;
+    QWidget *m_sideDockTitleWidget;
+    QWidget *m_leftSideWidget;
+    QVBoxLayout *m_leftLayout;
 
-    QHBoxLayout *leftTopLayout;
-    QVBoxLayout *userInfoLayout;
-    QToolBox *leftPanel;
+    QHBoxLayout *m_leftTopLayout;
+    QVBoxLayout *m_userInfoLayout;
+    QToolBox *m_minorFeedsPanel;
 
-    QAction *showMeanwhileFeed;
-    QAction *showMentionsFeed;
-    QAction *showActionsFeed;
+    QAction *m_showMeanwhileAction;
+    QAction *m_showMentionsAction;
+    QAction *m_showActionsAction;
 
     QWidget *m_rightSideWidget;
     QVBoxLayout *rightLayout;
-    QTabWidget *tabWidget;
+    QTabWidget *m_tabWidget;
     int m_tabsPosition;
     bool m_tabsMovable;
 
     // User profile widgets
-    QPushButton *avatarIconButton;
+    QPushButton *m_avatarIconButton;
     QString m_avatarUrl;
     QLabel *m_fullNameLabel;
     QLabel *m_userIdLabel;
     QLabel *m_userHometownLabel;
 
 
-    QSystemTrayIcon *trayIcon;
-    bool trayIconAvailable;
-    int trayIconType;
-    QPixmap trayCustomPixmap;
-    int trayCurrentNewCount;
-    int trayCurrentHLCount;
+    QSystemTrayIcon *m_trayIcon;
+    bool m_trayIconAvailable;
+    int m_trayIconType;
+    QPixmap m_trayCustomPixmap;
+    int m_trayCurrentNewCount;
+    int m_trayCurrentHLCount;
 
 
     GlobalObject *globalObject;
@@ -344,12 +344,13 @@ private:
     FilterEditor *m_filterEditor;
     LogViewer *m_logViewer;
     HelpWidget *m_helpWidget;
+
     PumpController *pumpController;
     FDNotifications *m_fdNotifications;
 
-    MinorFeed *meanwhileFeed;
-    MinorFeed *mentionsFeed;
-    MinorFeed *actionsFeed;
+    MinorFeed *m_meanwhileFeed;
+    MinorFeed *m_mentionsFeed;
+    MinorFeed *m_actionsFeed;
 
     BannerNotification *m_bannerNotification;
 
@@ -365,10 +366,10 @@ private:
     TimeLine *favoritesTimeline;
     QScrollArea *favoritesTimelineScrollArea;
 
+    ContactManager *m_contactManager;
 
-    ContactManager *contactManager;
 
-    Publisher *publisher;
+    Publisher *m_publisher;
 
 #ifdef HAVE_SONNET_SPELLCHECKER
     Sonnet::ConfigDialog *m_spellConfigDialog;
@@ -379,28 +380,29 @@ private:
 #endif
 
 
-    bool firstRun;
-    QString dataDirectory; // will have /images, /avatars, etc
-    bool reallyQuitProgram;
-    bool initializationComplete;
+    bool m_firstRun;
+    QString m_dataDirectory; // Will have /images, /avatars, etc
+    bool m_reallyQuitProgram;
+    bool m_initComplete;
 
-    int postIdsToStore;
+    int m_postIdsToStore;
 
 
     // Timer stuff
-    int updateInterval;
-    QTimer *updateTimer;
+    int m_updateInterval;
+    QTimer *m_updateTimer;
+
+    QTimer *m_timestampsTimer;
+    QTimer *m_delayedResizeTimer;
+    QTimer *m_postInitTimer;
+    QTimer *m_favoritesReloadTimer;
+    QTimer *m_userDidSomethingTimer;
+    QTimer *m_delayedScrollTimer;
 
-    QTimer *timestampsTimer;
-    QTimer *delayedResizeTimer;
-    QTimer *postInitTimer;
-    QTimer *favoritesReloadTimer;
-    QTimer *userDidSomethingTimer;
-    QTimer *delayedScrollTimer;
 
     // Statusbar stuff
-    QString oldStatusBarMessage;
-    QString previousStatusFeedInfo;
+    QString m_oldStatusBarMessage;
+    QString m_previousStatusFeedInfo;
 
     // User account-related data
     QString m_userId;
