@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2022  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -589,7 +589,8 @@ void MinorFeedItem::paintEvent(QPaintEvent *event)
     int iconOffset = 0;
     if (subtle)
     {
-        iconPixmap = icon.pixmap(m_verbIconSizeSubtle, m_verbIconSizeSubtle);
+        iconPixmap = icon.pixmap(m_verbIconSizeSubtle, m_verbIconSizeSubtle)
+                         .scaled(m_verbIconSizeSubtle, m_verbIconSizeSubtle);
         if (m_verbIconType == 4) // icon-after, subtle
         {
             iconOffset =  m_verbIconSize / 2; // Based on original icon size
